@@ -83,7 +83,6 @@ tbl_format_setup_ <- function(x, width, ..., n, max_extra_cols) {
 #'
 #' @rdname tbl_format_setup
 #' @export
-#' @importFrom utils head
 tbl_format_setup.tbl <- function(x, width, ...,
                                  n, max_extra_cols) {
   "!!!!DEBUG tbl_format_setup.tbl()"
@@ -92,14 +91,14 @@ tbl_format_setup.tbl <- function(x, width, ...,
   rows <- nrow(x)
 
   if (is.na(rows)) {
-    df <- as.data.frame(head(x, n + 1))
+    df <- df_head(x, n + 1)
     if (nrow(df) <= n) {
       rows <- nrow(df)
     } else {
-      df <- df[seq_len(n), , drop = FALSE]
+      df <- vec_head(df, n)
     }
   } else {
-    df <- as.data.frame(head(x, n))
+    df <- df_head(x, n)
   }
 
   if (is.na(rows)) {
@@ -122,15 +121,17 @@ tbl_format_setup.tbl <- function(x, width, ...,
   # Body
   rownames(df) <- NULL
 
-  body <- ctl_colonnade(
+  colonnade <- ctl_colonnade(
     df,
     has_row_id = if (.row_names_info(x) > 0) "*" else TRUE,
     width = width,
     controller = x
   )
 
+  body <- colonnade$body
+
   # Extra columns
-  extra_cols <- attr(body, "extra_cols")
+  extra_cols <- colonnade$extra_cols
   extra_cols_total <- length(extra_cols)
 
   if (extra_cols_total > max_extra_cols) {
